@@ -37,7 +37,6 @@
 
     \section ban_fqanoptions OPTIONS
     \subsection ban_fqanoptie1 -banmapfile <gridmapfile>
-        When this option is set it will override the default path of the gridmapfile.
         It is advised to use an absolute path to the gridmapfile to avoid usage of the wrong file(path).
 
 \section ban_fqanReturnvalue RETURN VALUES
@@ -45,9 +44,6 @@
         \li LCMAPS_MOD_FAIL    : Failure
 
 
-\section ban_fqanErrors ERRORS
-        See bugzilla for known errors (http://marianne.in2p3.fr/datagrid/bugzilla/)
-
 \section ban_fqanSeeAlso SEE ALSO
         \ref lcmaps_poolaccount.mod "lcmaps_poolaccount.mod",
         \ref lcmaps_posix_enf.mod "lcmaps_posix_enf.mod",
@@ -88,7 +84,6 @@
 /******************************************************************************
                                 Definitions
 ******************************************************************************/
-#define LCMAPS_MAXGIDBUFFER 256
 #define PLUGIN_RUN      0
 #define PLUGIN_VERIFY   1
 
@@ -273,14 +268,9 @@ static int plugin_run_or_verify(
     char *              dn          = NULL; 
     int                 dn_cnt      = 0;
     char *              username    = NULL;
-    struct passwd       *user_info  = NULL;
     int                 i           = 0;
-    int                 cnt_sec_gid = 0;
-    gid_t *             sec_gid     = NULL;
     int                 rc          = 0;
 
-    char **             vo_cred_string_list = NULL;
-    int                 cnt_vo_cred_string  = 0;
     int                 found               = 0;
     unsigned short      matching_type       = ((unsigned short)0x0000);
     char **             fqan_list           = NULL;
@@ -349,6 +339,11 @@ static int plugin_run_or_verify(
     if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) )
     {
 	nfqan = *(int *) value;
+	if (nfqan < 1)	{
+	    lcmaps_log(LOG_INFO,"%s: no (valid) VOMS groups found --> no mapping\n", logstr);
+	    goto success_ban_fqan;
+	}
+
         lcmaps_log_debug(5,"%s: the list of FQANs should contain %d elements\n", logstr, nfqan);
         if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv) ) )   {
 	    fqan_list = *(char ***) value;
@@ -363,26 +358,24 @@ static int plugin_run_or_verify(
         {
             lcmaps_log_debug(3, "%s: FQAN %d: %s\n", logstr, i, fqan_list[i]);
         }
-        vo_cred_string_list = fqan_list;
-        cnt_vo_cred_string = nfqan;
     }
     else
     {
         lcmaps_log_debug(1,"%s: ... did not find input credentials in input credential repository...\n", logstr);
         lcmaps_log_debug(1,"%s: ... trying the internal credential repository ...\n", logstr);
 
-        vo_cred_string_list = getCredentialData(LCMAPS_VO_CRED_STRING, &cnt_vo_cred_string);
-    }
+        fqan_list = getCredentialData(LCMAPS_VO_CRED_STRING, &nfqan);
 
-    if (cnt_vo_cred_string == 0)
-    {
-        lcmaps_log(LOG_NOTICE,"%s: no VOMS group info --> no mapping\n", logstr);
-        goto success_ban_fqan;
-    }
-    else if (cnt_vo_cred_string < 0)
-    {
-        lcmaps_log(LOG_ERR,"%s: negative number of VOMS groups found ! (failure)\n", logstr);
-        goto fail_ban_fqan;
+	if (nfqan == 0)
+	{
+	    lcmaps_log(LOG_INFO,"%s: zero VOMS groups found --> no mapping\n", logstr);
+	    goto success_ban_fqan;
+	}
+	else if (nfqan < 0)
+	{
+	    lcmaps_log(LOG_INFO,"%s: no valid VOMS credentials found -> no mapping\n", logstr);
+	    goto success_ban_fqan;
+	}
     }
 
 
@@ -399,22 +392,22 @@ static int plugin_run_or_verify(
     }
 
 
-    for (i = 0; i < cnt_vo_cred_string; i++) {
+    for (i = 0; i < nfqan; i++) {
         /* clean username before each call to lcmaps_gridlist */
         if (username)	{
 	    free(username);
 	    username = NULL;
 	}
-	rc = lcmaps_gridlist(vo_cred_string_list[i], &username, banmapfile, matching_type, NULL, NULL);
+	rc = lcmaps_gridlist(fqan_list[i], &username, banmapfile, matching_type, NULL, NULL);
 	switch (rc) {
 	    case LCMAPS_MOD_NOFILE:
 		lcmaps_log(LOG_ERR, "%s: Could not find the banmapfile %s\n", logstr, banmapfile);
 		goto fail_ban_fqan;
 	    case LCMAPS_MOD_ENTRY :
-		lcmaps_log(LOG_NOTICE,"%s: FQAN \"%s\" is found on the ban list.\n", logstr, vo_cred_string_list[i]);
+		lcmaps_log(LOG_NOTICE,"%s: FQAN \"%s\" is found on the ban list.\n", logstr, fqan_list[i]);
 		goto fail_ban_fqan;
 	    case LCMAPS_MOD_NOENTRY :
-		lcmaps_log_debug(1,"%s: FQAN \"%s\" *not* found in the ban list, moving along.\n", logstr, vo_cred_string_list[i]);
+		lcmaps_log_debug(1,"%s: FQAN \"%s\" *not* found in the ban list, moving along.\n", logstr, fqan_list[i]);
 		break;
 	    default :
 		lcmaps_log(LOG_ERR,"%s: Something unexpected went wrong. lcmaps_gridlist() returned %d\n", logstr, rc);
@@ -444,7 +437,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char * logstr = "lcmaps_plugin_ban_fqan-plugin_terminate()";
 
