@@ -70,6 +70,7 @@ CVS Information:
 #include <stdlib.h>
 #include <pwd.h>
 #include <fnmatch.h>
+#include <ctype.h>
 
 #if HAVE_MALLOC_H
 #include <malloc.h>
@@ -116,7 +117,7 @@ typedef struct _gridmap_line_s {
  * Number of user id slots to allocate at a time
  * Arbitraty value, but must be >= 2.
  */
-#define USERID_CHUNK_SIZE       4
+#define USERID_CHUNK_SIZE       256
 
 /******************************************************************************
                           Module specific prototypes
@@ -548,7 +549,7 @@ gridmapdir_userid(char *     globusidp,
      encodedglobusidp = gridmapdir_urlencode(globusidp);
 
      /* Check if this lease is already available */
-     if (*useridp = gridmapdir_otherlink(encodedglobusidp))
+     if ( (*useridp = gridmapdir_otherlink(encodedglobusidp)) )
         lcmaps_log_debug (5, "%s: Found an existing lease: %s\n", __func__, *useridp);
 
      /*
@@ -695,118 +696,6 @@ gridmapdir_userid(char *     globusidp,
      return 0;
 }
 
-/******************************************************************************
-Function:   gridmapdir_globusid
-Description:
-        This is equivalent to globus_gss_assist_map_local_user but for the 
-        dynamic user ids in the gridmapdir: search through leases to find
-        which globusID corresponds to a local unix user id.
-        This is called by globus_gss_assist_map_local_user 
-
-Parameters: 
-        globus client name who requested authentication 
-        *userid returned userid name for local system. 
-
-Returns:
-        0 on success
-        !=0 on failure
-
-******************************************************************************/
-
-static int
-gridmapdir_globusid(char *     useridp,
-                    char **    globusidp)
-{
-     int              encodedptr = 0, decodedptr = 0;
-     char             *encodedglobusidp; 
-
-     if (useridp[0] == '/') return 1; /* must not be a subject DN */
-
-     encodedglobusidp = gridmapdir_otherlink(useridp);
-
-     if (encodedglobusidp == NULL) return 1; /* not leased */
-
-     *globusidp = malloc(strlen(encodedglobusidp));
-
-     while (encodedglobusidp[encodedptr] != '\0')
-     {
-            if (encodedglobusidp[encodedptr] == ':')
-            {
-              sprintf((*globusidp)+decodedptr,"\001%s",encodedglobusidp+encodedptr+1);
-              decodedptr += strlen(encodedglobusidp+encodedptr);
-              break;
-            }
-            if (encodedglobusidp[encodedptr] != '%')
-            {
-                (*globusidp)[decodedptr] = encodedglobusidp[encodedptr];
-                ++encodedptr;
-                ++decodedptr;
-            }
-            else /* must be a %HH encoded character */
-            {
-                /* even paranoids have enemies ... */
-                if (encodedglobusidp[encodedptr+1] == '\0') break;
-                if (encodedglobusidp[encodedptr+2] == '\0') break;
-
-                (*globusidp)[decodedptr] = 
-                   xdigit_to_value(encodedglobusidp[encodedptr+1]) * 16 +
-                   xdigit_to_value(encodedglobusidp[encodedptr+2]);
-
-                encodedptr = encodedptr + 3;
-                ++decodedptr;
-            }
-     }
-
-     free(encodedglobusidp);
-     (*globusidp)[decodedptr] = '\0';
-     return 0;
-}
-
-/******************************************************************************
-Function:   gridmapdir_userok
-Description:
-        This is equivalent to globus_gss_assist_userok but for the dynamic
-        user ids in the gridmapdir: finds the local unix username leased to 
-        a globusID and compare with the username being checked.
-        This is called by globus_gss_assist_userok if the local user id in
-        the static gridmap file is -  (for a dynamic id)
-
-Parameters: 
-        globus client name who requested authentication 
-        userid to be checked
-
-Returns:
-        0 on success (authorization allowed)
-        !=0 on failure or authorization denied
-                
-******************************************************************************/
-
-static int
-gridmapdir_userok(char *     globusidp,
-                  char *     userid)
-{
-     char                    *encodedglobusidp, *leasedname;
-
-     if (globusidp[0] != '/') return 1; /* must be a proper subject DN */
-
-     encodedglobusidp = gridmapdir_urlencode(globusidp);
-     leasedname       = gridmapdir_otherlink(encodedglobusidp);
-     free(encodedglobusidp);
-
-     if (leasedname == NULL) return 1;
-
-     if (strcmp(userid, leasedname) == 0)
-     {
-         free(leasedname);
-         return 0;
-     }
-     else
-     {
-         free(leasedname);
-         return 1;
-     }
-}
-
 /******************************************************************************
                      End of gridmapdir functions
 ******************************************************************************/
@@ -1166,6 +1055,7 @@ gridmap_find_dn(const char * const  dn,
     FILE *              gmap_stream = NULL;
     int                 found = 0;
     gridmap_line_t *    gline_tmp;
+    int i;
 
 
     /* Check arguments */
@@ -1222,25 +1112,38 @@ gridmap_find_dn(const char * const  dn,
             }
             else if (gline_tmp->user_ids != NULL)
             {
-                tmp_name = (gline_tmp->user_ids[0]);
                 if (searchstr)
                 {
-                    if ( ((matching_type&MATCH_INCLUDE) == MATCH_INCLUDE) &&
-                         (strncmp(tmp_name, searchstr, strlen(searchstr)) == 0))
-                    {
-                        found = 1;
-                    }
-                    else if ( !((matching_type&MATCH_INCLUDE) == MATCH_INCLUDE) &&
-                             (strncmp(tmp_name, searchstr, strlen(searchstr)) != 0))
-                    {
-                        found = 1;
-                    } 
-                    else
-                    {
-                        gridmap_free_gridmap_line(gline_tmp);
-                        gline_tmp = NULL;
-                        found = 0;
-                    }
+		    if ((matching_type & MATCH_EXACT) == MATCH_EXACT)	{
+			for (i=0; (tmp_name=gline_tmp->user_ids[i])!=NULL; i++)	{
+			    if (strcmp(tmp_name, searchstr) == 0)   {
+				/* Swap current entry with first, to make match
+				 * the first entry */
+				gline_tmp->user_ids[i]=gline_tmp->user_ids[0];
+				gline_tmp->user_ids[0]=tmp_name;
+				found = 1;
+				break;
+			    }
+			}
+		    } else {
+			tmp_name = (gline_tmp->user_ids[0]);
+			if ( ((matching_type&MATCH_INCLUDE) == MATCH_INCLUDE) &&
+			     (strncmp(tmp_name, searchstr, strlen(searchstr)) == 0))
+			{
+			    found = 1;
+			}
+			else if ( !((matching_type&MATCH_INCLUDE) == MATCH_INCLUDE) &&
+				 (strncmp(tmp_name, searchstr, strlen(searchstr)) != 0))
+			{
+			    found = 1;
+			} 
+			else
+			{
+			    gridmap_free_gridmap_line(gline_tmp);
+			    gline_tmp = NULL;
+			    found = 0;
+			}
+		    }
                 }
                 else
                 {
