@@ -122,7 +122,6 @@
 #include "lcmaps_voms_gsi_utils.h"
 
 #include <voms/voms_apic.h>
-#include <globus_gss_assist.h>
 
 #undef TESTBIO
 #ifdef TESTBIO
@@ -660,7 +659,7 @@ static int plugin_run_or_verify(
 #endif
 
     /* succes */
- success_voms:
+/* success_voms:*/
     if (px509_cred) X509_free(px509_cred);
     if (px509_chain) sk_X509_free(px509_chain);
     lcmaps_log(LOG_INFO,"%s: voms plugin succeeded\n", logstr);
@@ -683,7 +682,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char * logstr = "lcmaps_plugin_voms-plugin_terminate()";
     lcmaps_log_debug(LOG_DEBUG,"%s: terminating\n", logstr);
