@@ -308,7 +308,6 @@ int plugin_introspect(
     int major=0,minor=0,patch=0;
     /* Most UNIX now support RTLD_DEFAULT (POSIX reserved) */
 #ifdef RTLD_DEFAULT
-    char *errorstr;
     int (*lcmaps_major)(void),(*lcmaps_minor)(void),(*lcmaps_patch)(void);
     dlerror();
     lcmaps_major=dlsym(RTLD_DEFAULT,"lcmaps_get_major_version");
@@ -410,8 +409,6 @@ static int plugin_run_or_verify(
     int                 i                   = 0;
     int                 cnt_sec_gid         = 0;
     gid_t *             sec_gid             = NULL;
-    char **             vo_cred_string_list = NULL;
-    int                 cnt_vo_cred_string  = 0;
     int                 found               = 0;
     unsigned short      matching_type       = ((unsigned short)0x0000);
     int                 rc                  = 0;
@@ -493,6 +490,11 @@ static int plugin_run_or_verify(
     if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) )
     {
 	nfqan = *(int *)value;
+	if (nfqan < 1)	{
+	    lcmaps_log(LOG_ERR,"%s: no (valid) VOMS groups found --> no mapping\n", logstr);
+	    goto fail_voms_localaccount;
+	}
+
         lcmaps_log_debug(5,"%s: the list of FQANs should contain %d elements\n", logstr, nfqan);
         if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv)) )   {
 	    fqan_list = *(char ***)value;
@@ -507,23 +509,21 @@ static int plugin_run_or_verify(
         {
             lcmaps_log_debug(3, "%s: FQAN %d: %s\n", logstr, i, fqan_list[i]);
         }
-        vo_cred_string_list = fqan_list;
-        cnt_vo_cred_string = nfqan;
     }
     else
     {
         lcmaps_log_debug(1,"%s: ... did not find input credentials in input credential repository...\n", logstr);
         lcmaps_log_debug(1,"%s: ... trying the internal credential repository ...\n", logstr);
 
-        vo_cred_string_list = getCredentialData(LCMAPS_VO_CRED_STRING, &cnt_vo_cred_string);
+        fqan_list = getCredentialData(LCMAPS_VO_CRED_STRING, &nfqan);
     }
 
-    if (cnt_vo_cred_string == 0)
+    if (nfqan == 0)
     {
         lcmaps_log(LOG_NOTICE,"%s: no VOMS group info --> no mapping\n", logstr);
         goto fail_voms_localaccount;
     }
-    else if (cnt_vo_cred_string < 0)
+    else if (nfqan < 0)
     {
         lcmaps_log(LOG_ERR,"%s: negative number of VOMS groups found ! (failure)\n", logstr);
         goto fail_voms_localaccount;
@@ -545,12 +545,12 @@ static int plugin_run_or_verify(
     }
 
 
-    for (i = 0; i < cnt_vo_cred_string; i++)
+    for (i = 0; i < nfqan; i++)
     {
         /* clean username before each call to lcmaps_gridlist */
         if (username) free(username);
         username = NULL;
-        if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &username, gridmapfile, matching_type, searchstr, NULL)) == 0)
+        if ( (rc = lcmaps_gridlist(fqan_list[i], &username, gridmapfile, matching_type, searchstr, NULL)) == 0)
         {
             found = 1;
             lcmaps_log_debug(3,"%s: found username: %s\n", logstr, username);
@@ -564,14 +564,15 @@ static int plugin_run_or_verify(
         else
         {
 	    if (req_username)
-		lcmaps_log_debug(1, "%s: no localaccount available for group (%s) and requested user %s in %s\n", logstr, vo_cred_string_list[i], req_username, gridmapfile);
+		lcmaps_log_debug(1, "%s: no localaccount available for group (%s) and requested user %s in %s\n", logstr, fqan_list[i], req_username, gridmapfile);
 	    else
-		lcmaps_log_debug(1, "%s: no localaccount available for group (%s) in %s\n", logstr, vo_cred_string_list[i], gridmapfile);
+		lcmaps_log_debug(1, "%s: no localaccount available for group (%s) in %s\n", logstr, fqan_list[i], gridmapfile);
         }
     }
     if (found != 1)
     {
-        lcmaps_log(LOG_WARNING, "%s: Could not find a VOMS localaccount in %s (failure)\n", logstr, gridmapfile);
+	/* This should be at most a NOTICE */
+        lcmaps_log(LOG_NOTICE, "%s: Could not find a VOMS localaccount in %s (failure)\n", logstr, gridmapfile);
         goto fail_voms_localaccount;
     }
 
@@ -654,7 +655,7 @@ static int plugin_run_or_verify(
     }
 
     /* succes */
- success_voms_localaccount:
+/* success_voms_localaccount:*/
     if (username) free(username);
     lcmaps_log(LOG_INFO,"%s: voms_localaccount plugin succeeded\n", logstr);
     return LCMAPS_MOD_SUCCESS;
@@ -675,7 +676,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char * logstr = "lcmaps_plugin_voms_localaccount-plugin_terminate()";
 
