@@ -190,7 +190,8 @@ int plugin_initialize(
 )
 {
     char * logstr = "lcmaps_plugin_voms_localgroup-plugin_initialize()";
-    int i, j;
+    int i;
+    size_t j;
 
     lcmaps_log_debug(5,"%s: passed arguments:\n", logstr);
     for (i=0; i < argc; i++)
@@ -347,8 +348,6 @@ static int plugin_run_or_verify(
     char *                groupname           = NULL;
     struct group *        group_info          = NULL;
     int                   i                   = 0;
-    char **               vo_cred_string_list = NULL;
-    int                   cnt_vo_cred_string  = 0;
     int                   group_counter       = 0;
     int                   rc                  = 0;
     lcmaps_vo_mapping_t * lcmaps_vo_mapping   = NULL;
@@ -404,6 +403,11 @@ static int plugin_run_or_verify(
     if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) )
     {
 	nfqan = *(int *) value;
+	if (nfqan < 1)	{
+	    lcmaps_log(LOG_ERR,"%s: no (valid) VOMS groups found --> no mapping\n", logstr);
+	    goto fail_voms_localgroup;
+	}
+
         lcmaps_log_debug(1,"%s: the list of FQANs should contain %d elements\n", logstr, nfqan);
         if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv) ) )   {
 	    fqan_list = *(char ***) value;
@@ -418,23 +422,21 @@ static int plugin_run_or_verify(
         {
             lcmaps_log_debug(3, "%s: FQAN %d: %s\n", logstr, i, fqan_list[i]);
         }
-        vo_cred_string_list = fqan_list;
-        cnt_vo_cred_string = nfqan;
     }
     else
     {
         lcmaps_log_debug(1,"%s: ... did not find input credentials in input credential repository...\n", logstr);
         lcmaps_log_debug(1,"%s: ... trying the internal credential repository ...\n", logstr);
 
-        vo_cred_string_list = getCredentialData(LCMAPS_VO_CRED_STRING, &cnt_vo_cred_string);
+        fqan_list = getCredentialData(LCMAPS_VO_CRED_STRING, &nfqan);
     }
 
-    if (cnt_vo_cred_string == 0)
+    if (nfqan == 0)
     {
         lcmaps_log(LOG_INFO,"%s: no VOMS group info --> no mapping\n", logstr);
         goto fail_voms_localgroup;
     }
-    else if (cnt_vo_cred_string < 0)
+    else if (nfqan < 0)
     {
         lcmaps_log(LOG_ERR,"%s: negative number of VOMS groups found ! (failure)\n", logstr);
         goto fail_voms_localgroup;
@@ -456,12 +458,12 @@ static int plugin_run_or_verify(
      * Try to find the unix groups from the VO info in the groupmapfile
      * The first group (if found) should become the primary group
      */
-    for (i = 0; i < cnt_vo_cred_string; i++)
+    for (i = 0; i < nfqan; i++)
     {
         /* clean groupname before each call to lcmaps_gridlist */
         if (groupname) free(groupname);
         groupname = NULL;
-        if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &groupname, groupmapfile, MATCH_EXCLUDE|MATCH_WILD_CHARS, ".", NULL) ) == 0)
+        if ( (rc = lcmaps_gridlist(fqan_list[i], &groupname, groupmapfile, MATCH_EXCLUDE|MATCH_WILD_CHARS, ".", NULL) ) == 0)
         {
             lcmaps_log_debug(1,"%s: found groupname: %s\n", logstr, groupname);
             group_counter++;
@@ -486,7 +488,7 @@ static int plugin_run_or_verify(
                      * in the lcmaps_vo_mapping structure, which is added to the credential data
                      */
                     lcmaps_vo_mapping=lcmaps_createVoMapping(
-                        vo_cred_string_list[i],
+                        fqan_list[i],
                         groupname,
                         group_info->gr_gid
                     );
@@ -526,7 +528,7 @@ static int plugin_run_or_verify(
             lcmaps_log_debug(1,"%s: could not get value of groupname !\n", logstr);
             if (mapall)
             {
-                lcmaps_log(LOG_INFO,"%s: no mapping for VO group %s\n", logstr, vo_cred_string_list[i]);
+                lcmaps_log(LOG_INFO,"%s: no mapping for VO group %s\n", logstr, fqan_list[i]);
                 goto fail_voms_localgroup;
             }
         }
@@ -539,7 +541,7 @@ static int plugin_run_or_verify(
     }
 
     /* success */
- success_voms_localgroup:
+/* success_voms_localgroup:*/
     if (groupname) free(groupname);
     lcmaps_log(LOG_INFO,"%s: voms_localgroup plugin succeeded\n", logstr);
     return LCMAPS_MOD_SUCCESS;
@@ -560,7 +562,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char *           logstr = "lcmaps_plugin_voms_localgroup-plugin_terminate()";
 
