@@ -262,7 +262,8 @@ int plugin_initialize(
 )
 {
     char *  logstr = "lcmaps_plugin_voms_poolaccount-plugin_initialize()";
-    int i = 0, j = 0;
+    int i = 0;
+    size_t j = 0;
     struct stat s;
 
     lcmaps_log_debug(5,"%s: passed arguments:\n", logstr);
@@ -454,7 +455,6 @@ int plugin_introspect(
     int major=0,minor=0,patch=0;
     /* Most UNIX now support RTLD_DEFAULT (POSIX reserved) */
 #ifdef RTLD_DEFAULT
-    char *errorstr;
     int (*lcmaps_major)(void),(*lcmaps_minor)(void),(*lcmaps_patch)(void);
     dlerror();
     lcmaps_major=dlsym(RTLD_DEFAULT,"lcmaps_get_major_version");
@@ -570,7 +570,7 @@ Description:
           so this is checked for. In that case a ':' is inserted.
 
 Parameters:
-    mapping_max:  maximum number of account mappings for this user+FQANS combination
+    mymapping_max:  maximum number of account mappings for this user+FQANS combination
     mapcounter:   account mapping number
     leasename:    the leasename after which the mapcount string should be appended
 Returns:
@@ -578,7 +578,7 @@ Returns:
     NULL in case of error
 ******************************************************************************/
 static char * add_mapcount_to_leasename(
-        int mapping_max,
+        int mymapping_max,
         int mapcounter,
         const char * leasename
 )
@@ -587,7 +587,7 @@ static char * add_mapcount_to_leasename(
     int    newleasenamelen = 0;
     char * logstr = "lcmaps_plugin_voms_poolaccount-add_mapcount_to_leasename()";
 
-    if (mapping_max == LCMAPS_INVALID_MAPPING_MAX)
+    if (mymapping_max == LCMAPS_INVALID_MAPPING_MAX)
     {
         if (mapcounter < LCMAPS_MAPPING_MIN)
         {
@@ -619,7 +619,7 @@ static char * add_mapcount_to_leasename(
             return NULL;
         }
     }
-    else if (mapping_max >= LCMAPS_MAPPING_MIN)
+    else if (mymapping_max >= LCMAPS_MAPPING_MIN)
     {
         if (mapcounter < LCMAPS_MAPPING_MIN)
         {
@@ -628,7 +628,7 @@ static char * add_mapcount_to_leasename(
             lcmaps_log_debug(3,"%s: mapcounter not used, leasename unchanged\n", logstr);
             if (leasename) newleasename = strdup(leasename);
         }
-        else if (mapcounter <= mapping_max) /* Create a leasename */
+        else if (mapcounter <= mymapping_max) /* Create a leasename */
         {
             char mapcount_string[14];
 
@@ -647,18 +647,18 @@ static char * add_mapcount_to_leasename(
         }
         else
         {
-            lcmaps_log(LOG_ERR,"%s: the request for mapping nr. %d, exceeds the maximum of %d\n", logstr, mapcounter, mapping_max);
+            lcmaps_log(LOG_ERR,"%s: the request for mapping nr. %d, exceeds the maximum of %d\n", logstr, mapcounter, mymapping_max);
             return NULL;
         }
     }
-    else if (mapping_max == 0) /* This means no mapping is allowed at all! */
+    else if (mymapping_max == 0) /* This means no mapping is allowed at all! */
     {
         lcmaps_log(LOG_ERR,"%s: The maximum number of account mappings per credential set is zero, so nothing to map (failure)! (You may want to adjust the \"-max_mappings_per_credential\" configuration parameter!)\n", logstr);
         return NULL;
     }
     else
     {
-        lcmaps_log(LOG_ERR,"%s: Illegal value for \"-max_mappings_per_credential\" (%d). Should at least be %d (failure)\n", logstr, mapping_max, LCMAPS_MAPPING_MIN);
+        lcmaps_log(LOG_ERR,"%s: Illegal value for \"-max_mappings_per_credential\" (%d). Should at least be %d (failure)\n", logstr, mymapping_max, LCMAPS_MAPPING_MIN);
         return NULL;
     }
     return newleasename;
@@ -685,9 +685,7 @@ static int plugin_run_or_verify(
     gid_t *             sec_gid             = NULL;
     char *              gidstring           = NULL;
     char                gidbuffer[LCMAPS_MAXGIDBUFFER];
-    int                 index               = 0;
-    char **             vo_cred_string_list = NULL;
-    int                 cnt_vo_cred_string  = 0;
+    size_t              my_index               = 0;
     int                 found_mapping       = 0;
     char *              leasename           = NULL;
     int                 leasenamelen        = 0;
@@ -754,7 +752,7 @@ static int plugin_run_or_verify(
      */
     if (lcmaps_mode == PLUGIN_VERIFY)
     {
-        if ( (value = lcmaps_getArgValue("requested_uid", "uid_t", argc, argv)) > 0 )
+        if ( (value = lcmaps_getArgValue("requested_uid", "uid_t", argc, argv)) != NULL )
         {
             struct passwd * requested_user = NULL;
 	    requested_uid = *(uid_t *) value;
@@ -815,6 +813,11 @@ static int plugin_run_or_verify(
     if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) )
     {
 	nfqan = *(int *) value;
+	if (nfqan < 1)	{
+	    lcmaps_log(LOG_ERR,"%s: no (valid) VOMS groups found --> no mapping\n", logstr);
+	    goto fail_voms_poolaccount;
+	}
+
         lcmaps_log_debug(4,"%s: the list of FQANs should contain %d elements\n", logstr, nfqan);
         if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv) ) )   {
 	    fqan_list = *(char ***) value;
@@ -829,22 +832,21 @@ static int plugin_run_or_verify(
         {
             lcmaps_log_debug(3, "%s: FQAN %d: %s\n", logstr, i, fqan_list[i]);
         }
-        vo_cred_string_list = fqan_list;
-        cnt_vo_cred_string = nfqan;
+        nfqan = nfqan;
     }
     else
     {
         lcmaps_log_debug(1,"%s: ... did not find input credentials in input credential repository. Trying the internal credential repository ...\n", logstr);
 
-        vo_cred_string_list = getCredentialData(LCMAPS_VO_CRED_STRING, &cnt_vo_cred_string);
+        fqan_list = getCredentialData(LCMAPS_VO_CRED_STRING, &nfqan);
     }
 
-    if (cnt_vo_cred_string == 0)
+    if (nfqan == 0)
     {
         lcmaps_log(LOG_ERR,"%s: no VOMS group info --> no mapping (failure)\n", logstr);
         goto fail_voms_poolaccount;
     }
-    else if (cnt_vo_cred_string < 0)
+    else if (nfqan < 0)
     {
         lcmaps_log(LOG_ERR,"%s: negative number of VOMS groups found ! (failure)\n", logstr);
         goto fail_voms_poolaccount;
@@ -930,18 +932,18 @@ static int plugin_run_or_verify(
      * Cat the gids into a string
      */
     gidbuffer[0] = '\0';
-    index = 0;
+    my_index = 0;
     /* First the primary gids */
     for (i = 0; i < cnt_pri_gid; i++)
     {
         if ( ( group_info = getgrgid(pri_gid[i]) ) )
         {
             groupname = group_info->gr_name;
-            if ( (strlen(groupname) + 1) < (LCMAPS_MAXGIDBUFFER - index) )
+            if ( (strlen(groupname) + 1) < ((size_t)LCMAPS_MAXGIDBUFFER - my_index) )
             {
                 strncat(gidbuffer, ":", 1);
-                strncat(gidbuffer, groupname, (LCMAPS_MAXGIDBUFFER - index - 2));
-                index += strlen(groupname) + 1;
+                strncat(gidbuffer, groupname, (LCMAPS_MAXGIDBUFFER - my_index - 2));
+                my_index += strlen(groupname) + 1;
                 lcmaps_log_debug(3,"%s: primary groups, i=%d(%d), group_info->gr_name: %s\n", logstr,
                                  i,cnt_pri_gid,group_info->gr_name);
                 lcmaps_log_debug(3,"%s: gidbuffer: %s\n", logstr,gidbuffer);
@@ -966,11 +968,11 @@ static int plugin_run_or_verify(
             if ( ( group_info = getgrgid(sec_gid[i]) ) )
             {
                 groupname = group_info->gr_name;
-                if ( (strlen(groupname) + 1) < (LCMAPS_MAXGIDBUFFER - index) )
+                if ( (strlen(groupname) + 1) < ((size_t)LCMAPS_MAXGIDBUFFER - my_index) )
                 {
                     strncat(gidbuffer, ":", 1);
-                    strncat(gidbuffer, groupname, (LCMAPS_MAXGIDBUFFER - index - 2));
-                    index += strlen(groupname) + 1;
+                    strncat(gidbuffer, groupname, (LCMAPS_MAXGIDBUFFER - my_index - 2));
+                    my_index += strlen(groupname) + 1;
                     lcmaps_log_debug(3,"%s: secondary groups, i=%d(%d), group_info->gr_name: %s\n", logstr,
                                      i,cnt_sec_gid,group_info->gr_name);
                     lcmaps_log_debug(3,"%s: gidbuffer: %s\n", logstr,gidbuffer);
@@ -1025,11 +1027,11 @@ static int plugin_run_or_verify(
     if (strict_poolprefix_match)
         matching_type = matching_type|MATCH_STRICT_PREFIX_NUM;
 
-    for (i = 0; i < cnt_vo_cred_string; i++)
+    for (i = 0; i < nfqan; i++)
     {
         if ( (i > 0) && (require_primary_gid == 1) )
         {
-            lcmaps_log(LOG_ERR,"%s: no match (or no poolaccount available) for primary group (%s) in %s (failure)\n", logstr, vo_cred_string_list[0], gridmapfile);
+            lcmaps_log(LOG_ERR,"%s: no match (or no poolaccount available) for primary group (%s) in %s (failure)\n", logstr, fqan_list[0], gridmapfile);
             goto fail_voms_poolaccount;
         }
 
@@ -1058,7 +1060,7 @@ static int plugin_run_or_verify(
                     goto fail_voms_poolaccount;
                 }
 
-                if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
+                if ( (rc = lcmaps_gridlist(fqan_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
                 {
 		    /* in verify mode, requested_username!=NULL */
 		    if ( strcmp(username, requested_username) == 0)
@@ -1081,7 +1083,7 @@ static int plugin_run_or_verify(
                 else
                 {
                     lcmaps_log_debug(1, "%s: no match (or no poolaccount available) for group (%s), mapcount = %d, in %s\n",
-                                     logstr, vo_cred_string_list[i], imap, gridmapfile);
+                                     logstr, fqan_list[i], imap, gridmapfile);
                 }
             }
             if (found_mapping == 0) /* Let's try the legacy behaviour (use the (invalid) mapcounter) */
@@ -1097,7 +1099,7 @@ static int plugin_run_or_verify(
                     lcmaps_log(LOG_ERR, "%s: Error creating leasename including mapcounter (%d)\n", logstr, mapcounter);
                     goto fail_voms_poolaccount;
                 }
-                if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
+                if ( (rc = lcmaps_gridlist(fqan_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
                 {
 		    /* in verify mode, requested_username!=NULL */
 		    if ( strcmp(username, requested_username) == 0)
@@ -1136,7 +1138,7 @@ static int plugin_run_or_verify(
                 goto fail_voms_poolaccount;
             }
 
-            if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
+            if ( (rc = lcmaps_gridlist(fqan_list[i], &username, gridmapfile, matching_type, ".", newleasename)) == 0)
             {
                 if (lcmaps_mode == PLUGIN_VERIFY)
                 {
@@ -1151,7 +1153,7 @@ static int plugin_run_or_verify(
                     else
                     {
                         lcmaps_log_debug(1,"%s: The requested username \"%s\" was not found for %s in %s, mapcount=%d\n",
-                                         logstr, requested_username, vo_cred_string_list[i], gridmapfile, mapcounter);
+                                         logstr, requested_username, fqan_list[i], gridmapfile, mapcounter);
                     }
                 }
                 else
@@ -1182,7 +1184,7 @@ static int plugin_run_or_verify(
             }
             else
             {
-                lcmaps_log_debug(1, "%s: no match (or no poolaccount available) for group (%s) in %s\n", logstr, vo_cred_string_list[i], gridmapfile);
+                lcmaps_log_debug(1, "%s: no match (or no poolaccount available) for group (%s) in %s\n", logstr, fqan_list[i], gridmapfile);
             }
         }
     }
@@ -1301,7 +1303,7 @@ static int plugin_run_or_verify(
     }
 
     /* succes */
- success_voms_poolaccount:
+/* success_voms_poolaccount:*/
     if (requested_username) free(requested_username);
     if (username) free(username);
     if (leasename) free(leasename);
@@ -1328,7 +1330,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char * logstr = "lcmaps_plugin_voms_poolaccount-plugin_terminate()";
 
