@@ -243,7 +243,8 @@ int plugin_initialize(
 )
 {
     char *  logstr = "lcmaps_plugin_voms_poolgroup-plugin_initialize()";
-    int i, j;
+    int i;
+    size_t j;
     struct stat s;
 
     lcmaps_log_debug(5,"%s: passed arguments:\n", logstr);
@@ -458,8 +459,6 @@ static int plugin_run_or_verify(
     char *                  groupname           = NULL;
     struct group *          group_info          = NULL;
     int                     i                   = 0;
-    char **                 vo_cred_string_list = NULL;
-    int                     cnt_vo_cred_string  = 0;
     unsigned short          matching_type       = ((unsigned short)0x0000);
     int                     group_counter       = 0;
     int                     rc                  = 0;
@@ -493,11 +492,11 @@ static int plugin_run_or_verify(
      */
     if (lcmaps_mode == PLUGIN_VERIFY)
     {
-        if ( (value = lcmaps_getArgValue("requested_npgid", "int", argc, argv)) > 0 )
+        if ( (value = lcmaps_getArgValue("requested_npgid", "int", argc, argv)) != NULL )
         {
 	    requested_npgid = *(int *) value;
             lcmaps_log_debug(1,"%s: the list of pgids should contain %d elements\n", logstr, requested_npgid);
-            if ( ( value = lcmaps_getArgValue("requested_pgid_list", "gid_t *", argc, argv) ) )   {
+            if ( ( value = lcmaps_getArgValue("requested_pgid_list", "gid_t *", argc, argv) ) != NULL  )   {
 		requested_pgid_list = *(gid_t **) value;
                 lcmaps_log_debug(1, "%s: found list of pgids\n", logstr);
 	    }
@@ -511,11 +510,11 @@ static int plugin_run_or_verify(
                 lcmaps_log_debug(3, "%s: pgid[%d]: %d\n", logstr, i, (int)(requested_pgid_list[i]));
             }
         }
-        if ( (value = lcmaps_getArgValue("requested_nsgid", "int", argc, argv)) > 0 )
+        if ( (value = lcmaps_getArgValue("requested_nsgid", "int", argc, argv)) != NULL )
         {
 	    requested_nsgid = *(int *) value;
             lcmaps_log_debug(1,"%s: the list of sgids should contain %d elements\n", logstr, requested_nsgid);
-            if ( ( value = lcmaps_getArgValue("requested_sgid_list", "gid_t *", argc, argv) ) )   {
+            if ( ( value = lcmaps_getArgValue("requested_sgid_list", "gid_t *", argc, argv) ) != NULL )   {
 		requested_sgid_list = *(gid_t **) value;
                 lcmaps_log_debug(1, "%s: found list of sgids\n", logstr);
 	    }
@@ -541,11 +540,16 @@ static int plugin_run_or_verify(
      * The VOMS info has to matched against the info in the gridmapfile
      */
     lcmaps_log_debug(5,"%s: First try to get the FQAN list from input credential repository ...\n", logstr);
-    if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) )
+    if ( ( value = lcmaps_getArgValue("nfqan", "int", argc, argv) ) != NULL )
     {
 	nfqan = *(int *) value;
+	if (nfqan < 1)	{
+	    lcmaps_log(LOG_ERR,"%s: no (valid) VOMS groups found --> no mapping\n", logstr);
+	    goto fail_voms_poolgroup;
+	}
+
         lcmaps_log_debug(5,"%s: the list of FQANs should contain %d elements\n", logstr, nfqan);
-        if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv) ) )   {
+        if ( ( value = lcmaps_getArgValue("fqan_list", "char **", argc, argv) ) != NULL )   {
 	    fqan_list = *(char ***) value;
             lcmaps_log_debug(5, "%s: found list of FQANs\n", logstr);
 	}
@@ -558,21 +562,19 @@ static int plugin_run_or_verify(
         {
             lcmaps_log_debug(3, "%s: FQAN %d: %s\n", logstr, i, fqan_list[i]);
         }
-        vo_cred_string_list = fqan_list;
-        cnt_vo_cred_string = nfqan;
     }
     else
     {
         lcmaps_log_debug(1,"%s: ... did not find input credentials in input credential repository ... trying the internal credential repository ...\n", logstr);
-        vo_cred_string_list = getCredentialData(LCMAPS_VO_CRED_STRING, &cnt_vo_cred_string);
+        fqan_list = getCredentialData(LCMAPS_VO_CRED_STRING, &nfqan);
     }
 
-    if (cnt_vo_cred_string == 0)
+    if (nfqan == 0)
     {
         lcmaps_log(LOG_ERR,"%s: no VOMS group info --> no mapping (failure)\n", logstr);
         goto fail_voms_poolgroup;
     }
-    else if (cnt_vo_cred_string < 0)
+    else if (nfqan < 0)
     {
         lcmaps_log(LOG_ERR,"%s: negative number of VOMS groups found ! (failure)\n", logstr);
         goto fail_voms_poolgroup;
@@ -637,12 +639,12 @@ static int plugin_run_or_verify(
     if (lcmaps_mode == PLUGIN_VERIFY)
         matching_type = matching_type|ONLY_USE_EXISTING_LEASE;
 
-    for (i = 0; i < cnt_vo_cred_string; i++)
+    for (i = 0; i < nfqan; i++)
     {
         /* clean groupname before each call to lcmaps_gridlist */
         if (groupname) free(groupname);
         groupname = NULL;
-        if ( (rc = lcmaps_gridlist(vo_cred_string_list[i], &groupname, groupmapfile, matching_type, ".", NULL)) == 0)
+        if ( (rc = lcmaps_gridlist(fqan_list[i], &groupname, groupmapfile, matching_type, ".", NULL)) == 0)
         {
             lcmaps_log_debug(4,"%s: found groupname: %s\n", logstr, groupname);
             group_counter++;
@@ -667,7 +669,7 @@ static int plugin_run_or_verify(
                      * in the lcmaps_vo_mapping structure, which is added to the credential data
                      */
                     lcmaps_vo_mapping=lcmaps_createVoMapping(
-                        vo_cred_string_list[i],
+                        fqan_list[i],
                         groupname,
                         group_info->gr_gid
                     );
@@ -707,7 +709,7 @@ static int plugin_run_or_verify(
             lcmaps_log_debug(1,"%s: could not get value of groupname !\n", logstr);
             if (mapall)
             {
-                lcmaps_log(LOG_NOTICE,"%s: no mapping for VO group %s\n", logstr, vo_cred_string_list[i]);
+                lcmaps_log(LOG_NOTICE,"%s: no mapping for VO group %s\n", logstr, fqan_list[i]);
                 goto fail_voms_poolgroup;
             }
         }
@@ -720,7 +722,7 @@ static int plugin_run_or_verify(
     }
 
     /* success */
- success_voms_poolgroup:
+/* success_voms_poolgroup:*/
     if (groupname) free(groupname);
     lcmaps_log(LOG_INFO,"%s: voms_poolgroup plugin succeeded\n", logstr);
     return LCMAPS_MOD_SUCCESS;
@@ -741,7 +743,7 @@ Returns:
     LCMAPS_MOD_SUCCESS : succes
     LCMAPS_MOD_FAIL    : failure
 ******************************************************************************/
-int plugin_terminate()
+int plugin_terminate(void)
 {
     char * logstr = "lcmaps_plugin_voms_poolgroup-plugin_terminate()";
 
